# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"printDict": "dictUtil.ipynb",
         "errorString": "exception.ipynb",
         "add_method": "wrappers.ipynb"}

modules = ["dictUtil.py",
           "exception.py",
           "wrappers.py"]

doc_url = "https://nic.github.io/nicHelper/"

git_url = "https://github.com/nic/nicHelper/tree/master/"

def custom_doc_links(name): return None
